Enum orchestrator::executor::Error
source · pub enum Error {
Generic(Box<dyn StdError + Send + Sync + 'static>),
NotFound,
CycleDetected,
UnregisteredExecutor,
Json(Error),
}Expand description
Type that represent all error that a generic executor could trigger
Variants
Generic(Box<dyn StdError + Send + Sync + 'static>)
generic Boxed Error, It should Be used as little as possible
NotFound
Not found an implementation fot that particular executor
CycleDetected
detected a cycle
UnregisteredExecutor
Not found an implementation fot that particular executor
Json(Error)
Impossible to serialize, something is wrong