Trait orchestrator::executor::ExecutorGlobalState

source ·
pub trait ExecutorGlobalState: Clone + TryInto<ExerciseResult> + Send + Sync + 'static {
    // Required methods
    fn serialize_variant(&self) -> String;
    fn deserialize_variant(
        s: &str,
    ) -> Result<TypeId, Box<dyn StdError + Send + Sync + 'static>>;
}
This trait is implemented for a State managable by the orchestrator. It is strongly advises to using the provided macro to generate it

Required Methods

source

fn serialize_variant(&self) -> String

Transform the current variant in a String

source

fn deserialize_variant( s: &str, ) -> Result<TypeId, Box<dyn StdError + Send + Sync + 'static>>

Recover the variant from string, and returns the respective TypeId

Object Safety

This trait is not object safe.

Implementors