Trait orchestrator::executor::AsyncDefault
source · pub trait AsyncDefault {
// Required method
fn async_default() -> impl Future<Output = Self>;
}Expand description
Some implementations require async in order to generate a Default object. This trait is a wrapper around standard Default trait, and extends it automatically.
Required Methods
sourcefn async_default() -> impl Future<Output = Self>
fn async_default() -> impl Future<Output = Self>
Same function as Default::default(), but async
Object Safety
This trait is not object safe.